```{highlight} shell
```

# Installation

## Stable release

To install Python Deft Lariats, run this command in your terminal:

```console
$ pip install PyDeftLariats
```

This is the preferred method to install Python Deft Lariats, as it will always install the most recent stable release.

If you don't have [pip] installed, this [Python installation guide] can guide
you through the process.

## From sources

The sources for Python Deft Lariats can be downloaded from the [Github repo].

You can either clone the public repository:

```console
$ git clone git://github.com/mcmasty/PyDeftLariats
```

Or download the [tarball]:

```console
$ curl -OJL https://github.com/mcmasty/PyDeftLariats/tarball/master
```

Once you have a copy of the source, you can install it with:

```console
$ python setup.py install
```

[github repo]: https://github.com/mcmasty/PyDeftLariats
[pip]: https://pip.pypa.io
[python installation guide]: http://docs.python-guide.org/en/latest/starting/installation/
[tarball]: https://github.com/mcmasty/src/tarball/master
